==> wildfly-server-8.0.0.Final-sources.jar: org/jboss/as/server/services/net/BindingMulticastAddressHandler.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2011 Red Hat Inc. and/or its affiliates and other contributors
 * as indicated by the @authors tag. All rights reserved.
 * See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This copyrighted material is made available to anyone wishing to use,
 * modify, copy, or redistribute it subject to the terms and conditions
 * of the GNU Lesser General Public License, v. 2.1.
 * This program is distributed in the hope that it will be useful, but WITHOUT A
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
 * PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License,
 * v.2.1 along with this distribution; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA  02110-1301, USA.
 */
package org.jboss.as.server.services.net;

import java.net.InetAddress;
import java.net.UnknownHostException;

import org.jboss.as.controller.OperationFailedException;
import org.jboss.as.controller.resource.AbstractSocketBindingResourceDefinition;
import org.jboss.as.network.SocketBinding;
import org.jboss.as.server.ServerMessages;
import org.jboss.dmr.ModelNode;

/**
 * Handler for changing the interface on a socket binding.
 *
 * @author Brian Stansberry (c) 2011 Red Hat Inc.
 */
public class BindingMulticastAddressHandler extends AbstractBindingWriteHandler {

    public static final BindingMulticastAddressHandler INSTANCE = new BindingMulticastAddressHandler();

    private BindingMulticastAddressHandler() {
        super(AbstractSocketBindingResourceDefinition.MULTICAST_ADDRESS);
    }

    @Override
    void handleRuntimeChange(ModelNode operation, String attributeName, ModelNode attributeValue, SocketBinding binding) throws OperationFailedException {
        final InetAddress address;
        if(attributeValue.isDefined()) {
            String addrString = attributeValue.asString();
            try {
                address = InetAddress.getByName(addrString);
            } catch (UnknownHostException e) {
                throw ServerMessages.MESSAGES.failedToResolveMulticastAddress(e, addrString);
            }
        } else {
            address = null;
        }
        binding.setMulticastAddress(address);
    }

    @Override
    void handleRuntimeRollback(ModelNode operation, String attributeName, ModelNode attributeValue, SocketBinding binding) {
        final InetAddress address;
        if(attributeValue.isDefined()) {
            String addrString = attributeValue.asString();
            try {
                address = InetAddress.getByName(addrString);
            } catch (UnknownHostException e) {
                throw ServerMessages.MESSAGES.failedToResolveMulticastAddressForRollback(e, addrString);
            }
        } else {
            address = null;
        }
        binding.setMulticastAddress(address);
    }
}

==> wildfly-server-25.0.2.Final-sources.jar: org/jboss/as/server/services/net/BindingMulticastAddressHandler.java <==
/*
 * Copyright The WildFly Authors
 * SPDX-License-Identifier: Apache-2.0
 */
package org.jboss.as.server.services.net;

import java.net.InetAddress;
import java.net.UnknownHostException;

import org.jboss.as.controller.OperationContext;
import org.jboss.as.controller.OperationFailedException;
import org.jboss.as.controller.resource.AbstractSocketBindingResourceDefinition;
import org.jboss.as.network.SocketBinding;
import org.jboss.as.server.logging.ServerLogger;
import org.jboss.dmr.ModelNode;

/**
 * Handler for changing the interface on a socket binding.
 *
 * @author Brian Stansberry (c) 2011 Red Hat Inc.
 */
public class BindingMulticastAddressHandler extends AbstractBindingWriteHandler {

    public static final BindingMulticastAddressHandler INSTANCE = new BindingMulticastAddressHandler();

    private BindingMulticastAddressHandler() {
        super(AbstractSocketBindingResourceDefinition.MULTICAST_ADDRESS);
    }

    @Override
    void handleRuntimeChange(OperationContext context, ModelNode operation, String attributeName, ModelNode attributeValue, SocketBinding binding) throws OperationFailedException {
        final InetAddress address;
        if(attributeValue.isDefined()) {
            String addrString = attributeValue.asString();
            try {
                address = InetAddress.getByName(addrString);
            } catch (UnknownHostException e) {
                throw ServerLogger.ROOT_LOGGER.failedToResolveMulticastAddress(e, addrString);
            }
        } else {
            address = null;
        }
        binding.setMulticastAddress(address);
    }

    @Override
    void handleRuntimeRollback(OperationContext context, ModelNode operation, String attributeName, ModelNode attributeValue, SocketBinding binding) {
        final InetAddress address;
        if(attributeValue.isDefined()) {
            String addrString = attributeValue.asString();
            try {
                address = InetAddress.getByName(addrString);
            } catch (UnknownHostException e) {
                throw ServerLogger.ROOT_LOGGER.failedToResolveMulticastAddressForRollback(e, addrString);
            }
        } else {
            address = null;
        }
        binding.setMulticastAddress(address);
    }
}
